"""
[Mar. 2021] 2018 Chicago Salaries - Mina Pecheux

A quick ML study of open-source data to show the importance of the training
dataset in machine learning models predictions.
===========================================================================
STEP 2: DATA ANALYSIS
---------------------
Do a quick statistical analysis of the data to get the mean salaries, the
repartition by gender and other interesting insights about the dataset.
"""

import pandas as pd
import matplotlib.pyplot as plt

if __name__ == '__main__':
  # 1. import prepared dataset + separate men/women populations
  print('1. Importing prepared data')
  df = pd.read_csv('datasets/chicago_employees_prepared.csv')

  only_males = df[df['Gender'] == 'male']
  only_females = df[df['Gender'] == 'female']

  # 2. compare number of samples
  print('2. Comparing the number of samples:')
  n = len(df)
  n_males = len(only_males)
  n_females = len(only_females)
  print('Number of men in the dataset:   {:5d}/{:5d} ({:.2f}%)'
    .format(n_males, n, 100.0 * n_males / n))
  print('Number of women in the dataset: {:5d}/{:5d} ({:.2f}%)'
    .format(n_females, n, 100.0 * n_females / n), end='\n\n')

  # 3. get the mean salaries for each gender
  salary_by_gender = pd.DataFrame({
    'male': only_males['Annual Salary'],
    'female': only_females['Annual Salary'],
  })
  mean_salaries = salary_by_gender.mean()
  print('3. Getting mean salaries by gender (in $/year):')
  print(mean_salaries)
  print('')

  # 4. plot the annual salary repartition by gender (with the means)
  print('4. Plotting the annual salary repartition by gender (with the means)')
  salary_by_gender.plot.hist(bins=80, alpha=0.4, color=['blue', 'red'])
  plt.vlines(x=mean_salaries['male'], ymin=0, ymax=3000, color='blue')
  plt.vlines(x=mean_salaries['female'], ymin=0, ymax=3000, color='red')
  plt.title('Annual salary repartition by gender')
  plt.xlabel('Annual salary ($)')
  plt.ylabel('Number of employees')
  plt.show()
